@@ -13,17 +13,19 @@
 class QLabelW: public QLabel {
 
 public:
-	QLabelW(const QString &text, QWidget *parent=0, Qt::WindowFlags f=0) : QLabel (text, parent, f) {
+	QLabelW(const QString &text, bool isLabel, QWidget *parent=0, Qt::WindowFlags f=0) : QLabel (text, parent, f) {
+		this->isLabel = isLabel;
 	}
 	QLabelW(QWidget *parent=0, Qt::WindowFlags f=0): QLabel (parent, f) {
 	}
 	~QLabelW() {
 	}
 protected:
+	bool isLabel;
     void mousePressEvent(QMouseEvent *ev) {
     	//qDebug () << "click on field " << this->userData(0);
     	TargetField * f = ((ButtonInfo *)this->userData(0))->field;
-    	if (f->type == TYPE_URL) {
+    	if (f->type == TYPE_URL && !isLabel) {
     		QDesktopServices::openUrl(QUrl::fromUserInput(f->value));
     	}
     	else {
@@ -347,7 +349,7 @@ void DetailWindow::showFields () {
 			}
 			else {
 				if (field->value.length() > 0) {
-					QLabel * nameLabel = new QLabelW(field->name, this);
+					QLabel * nameLabel = new QLabelW(field->name, true, this);
 					nameLabel->setFont (QFont("arial", 11, 1, true));
 					nameLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 					nameLabel->setContentsMargins(0, 0, 10, 0);
@@ -367,7 +369,7 @@ void DetailWindow::showFields () {
 						QObject::connect(nameLineEdit, SIGNAL(clicked()), signalMapper, SLOT(map()));
 					}
 					else {
-						QLabel * nameLineEdit = new QLabelW(field->value, this);
+						QLabel * nameLineEdit = new QLabelW(field->value, false, this);
 						nameLineEdit->setUserData(0, new ButtonInfo (field));
 						componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 //						if (field->type == TYPE_URL) {
