@@ -17,9 +17,10 @@ class LoginDialog : public QWidget
 	Q_OBJECT
 
 public:
-	LoginDialog(eWallet * paTarget);
+	LoginDialog(bool firstTime, eWallet * paTarget);
 	~LoginDialog();
 
+	void resetF ();
 	void keyPressEvent(QKeyEvent* event);
 
 private slots:
@@ -30,12 +31,16 @@ private slots:
 
 private:
 	QPointer<AboutDialog> aboutDialogDlg;
-
+	QPointer <QMessageBox> messageBox;
 	//void focusOutEvent ( QFocusEvent * event );
 	QString current;
 	QString repeat;
 	eWallet * parent;
 	
+	int NTimes;
+	bool isFirstTime;
+	QString newPassword;
+
 	QLabel * label;
 };
 #endif // LOGINDIALOG_H
